@@ -45,15 +45,6 @@ func TestIsIOHealthy(t *testing.T) {
 	checkPodsLogs(t, `The operator is healthy`)
 }
 
-// Check if an archive is uploaded and insights results retrieved in a reasonable amount of time
-// This test can be performed on OCP 4.7 and newer
-func TestArchiveUploadedAndResultReceived(t *testing.T) {
-	start := logLineTime(t, `Reporting status periodically to .* every`)
-	end := logLineTime(t, `Successfully reported id=`)
-	uploadingTime := duration(t, start, end)
-	t.Logf("Archive upload time is %v seconds", uploadingTime)
-}
-
 // Check if opt-in/opt-out works
 func TestOptOutOptIn(t *testing.T) {
 	// initially IO should be running
